This module is created for the demo purpose, which will return true or false whether the given number is prime or not.
For a full description, how to create package
[project page](https://packaging.python.org/en/latest/tutorials/packaging-projects/).